# Django Ninja Auth

A one stop shop for all your Django-Ninja Authentication needs.
Supports REST authentication with Sessions, Auth Tokens and JWTs.

Fully Customisable to suit your needs.

This repository does not fix any issues in SimpleJWT or django-ninja-jwt.
It is intended to build upon the repository and add other forms of authentication on top of just JWTs.

[Documentation](https://bhargav.io/ninja-auth/)
